@@ -27,7 +27,7 @@ class ActorFilter(NameSlugSearchFilterSet):
             Q(name__icontains=value)
             | Q(telephone__icontains=value)
             | Q(cellphone__icontains=value)
-            | Q(emails__icontains=value)
+            | Q(email__icontains=value)
         )
 
         return queryset.filter(qs_filter)
